@@ -88,7 +88,7 @@ class Aggregator:
         self.max_daily_ghi = None
         self.min_daily_temp = None
         self.prev_load = None
-        self.dt = int(self.config['agg']['subhourly_steps'])
+        self.dt = min(2, int(self.config['agg']['subhourly_steps'])) # temporary reporting issue with dt == 1
         self._set_dt()
         self.ts_data = self._import_ts_data() # Temp: degC, RH: %, Pressure: mbar, GHI: W/m2
         
@@ -183,6 +183,12 @@ class Aggregator:
         df.filter(df_interp.index, axis=0)
         df.bfill(inplace=True)
 
+        if self.dt == 1:
+            print(type(df["Minute"].iloc[2]), df["Minute"].iloc[2])
+            df["Minute"] = 0.0
+            df["ts"] = pd.to_datetime(df[['Year','Month','Day','Hour','Minute']])
+            df.set_index('ts', inplace=True)
+
         self.oat = df['OAT'].to_numpy()
         self.ghi = df['GHI'].to_numpy()
 
@@ -675,10 +681,10 @@ class Aggregator:
         house_load = {}
         self.forecast_house_load = []
         
-        if self.timestep % (24 * self.dt) == 0: # at the end of the day
-            self.daily_peak = 0.01 # remove if we want the max peak of the simulation
-            for k,v in self.contribution2peak.items():
-                self.redis_client.hset("peak_contribution", k, v)
+        # if self.timestep % (24 * self.dt) == 0: # at the end of the day
+        #     self.daily_peak = 0.01 # remove if we want the max peak of the simulation
+        #     for k,v in self.contribution2peak.items():
+        #         self.redis_client.hset("peak_contribution", k, v)
 
         for home in self.all_homes:
             if self.check_type == 'all' or home["type"] == self.check_type:
@@ -701,7 +707,9 @@ class Aggregator:
         if self.agg_load >= self.daily_peak:
             self.daily_peak = self.agg_load
             self.contribution2peak = {k:house_load[k]/self.daily_peak for k,v in self.contribution2peak.items()}
-
+            for k,v in self.contribution2peak.items():
+                self.redis_client.hset("peak_contribution", k, v)
+                
         self.forecast_load = np.sum(self.forecast_house_load)
         self.agg_cost = agg_cost
         self.baseline_agg_load_list.append(self.agg_load)
@@ -751,6 +759,7 @@ class Aggregator:
             "case": self.case,
             "start_datetime": self.start_dt.strftime('%Y-%m-%d %H'),
             "end_datetime": self.end_dt.strftime('%Y-%m-%d %H'),
+            "num_timesteps": self.num_timesteps,
             "solve_time": self.t_diff.total_seconds(),
             "horizon": self.config['home']['hems']['prediction_horizon'],
             "num_homes": self.config['community']['total_number_homes'],
